# Generated by Django 3.0.5 on 2020-09-14 10:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0020_auto_20200914_1041"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="jurisdiction",
            name="feature_flags",
        ),
    ]
