# Generated by Django 3.2.2 on 2021-09-14 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "data",
            "0037_importobjects_runplan_scrapeobjects_scrapereport_sessiondataqualityreport",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="event",
            name="deleted",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="event",
            name="upstream_id",
            field=models.CharField(blank=True, max_length=300),
        ),
    ]
